==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/IpPrefixPropertiesIpPrefixRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.IpPrefixPropertiesIpPrefixRulesArgs.builder
import com.pulumi.azurenative.managednetworkfabric.kotlin.enums.CommunityActionTypes
import com.pulumi.azurenative.managednetworkfabric.kotlin.enums.Condition
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property action Action to be taken on the configuration. Example: Permit | Deny.
 * @property condition Specify prefix-list bounds.
 * @property networkPrefix Network Prefix specifying IPv4/IPv6 packets to be permitted or denied. Example: 1.1.1.0/24 | 3FFE:FFFF:0:CD30::/126
 * @property sequenceNumber Sequence to insert to/delete from existing route. Prefix lists are evaluated starting with the lowest sequence number and continue down the list until a match is made. Once a match is made, the permit or deny statement is applied to that network and the rest of the list is ignored.
 * @property subnetMaskLength SubnetMaskLength gives the minimum NetworkPrefix length to be matched.Possible values for IPv4 are 1 - 32. Possible values of IPv6 are 1 - 128.
 */
public data class IpPrefixPropertiesIpPrefixRulesArgs(
    public val action: Output<Either<String, CommunityActionTypes>>,
    public val condition: Output<Either<String, Condition>>? = null,
    public val networkPrefix: Output<String>,
    public val sequenceNumber: Output<Double>,
    public val subnetMaskLength: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.IpPrefixPropertiesIpPrefixRulesArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.IpPrefixPropertiesIpPrefixRulesArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.IpPrefixPropertiesIpPrefixRulesArgs.builder()
            .action(
                action.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .condition(
                condition?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .networkPrefix(networkPrefix.applyValue({ args0 -> args0 }))
            .sequenceNumber(sequenceNumber.applyValue({ args0 -> args0 }))
            .subnetMaskLength(subnetMaskLength?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IpPrefixPropertiesIpPrefixRulesArgs].
 */
@PulumiTagMarker
public class IpPrefixPropertiesIpPrefixRulesArgsBuilder internal constructor() {
    private var action: Output<Either<String, CommunityActionTypes>>? = null

    private var condition: Output<Either<String, Condition>>? = null

    private var networkPrefix: Output<String>? = null

    private var sequenceNumber: Output<Double>? = null

    private var subnetMaskLength: Output<Int>? = null

    /**
     * @param value Action to be taken on the configuration. Example: Permit | Deny.
     */
    @JvmName("ljayccwiwpnomtbh")
    public suspend fun action(`value`: Output<Either<String, CommunityActionTypes>>) {
        this.action = value
    }

    /**
     * @param value Specify prefix-list bounds.
     */
    @JvmName("dchdyimqmywgylta")
    public suspend fun condition(`value`: Output<Either<String, Condition>>) {
        this.condition = value
    }

    /**
     * @param value Network Prefix specifying IPv4/IPv6 packets to be permitted or denied. Example: 1.1.1.0/24 | 3FFE:FFFF:0:CD30::/126
     */
    @JvmName("uvtquloifiwnavgn")
    public suspend fun networkPrefix(`value`: Output<String>) {
        this.networkPrefix = value
    }

    /**
     * @param value Sequence to insert to/delete from existing route. Prefix lists are evaluated starting with the lowest sequence number and continue down the list until a match is made. Once a match is made, the permit or deny statement is applied to that network and the rest of the list is ignored.
     */
    @JvmName("krxjvwtdhwsndtwj")
    public suspend fun sequenceNumber(`value`: Output<Double>) {
        this.sequenceNumber = value
    }

    /**
     * @param value SubnetMaskLength gives the minimum NetworkPrefix length to be matched.Possible values for IPv4 are 1 - 32. Possible values of IPv6 are 1 - 128.
     */
    @JvmName("uvhhctlbkuecxkoy")
    public suspend fun subnetMaskLength(`value`: Output<Int>) {
        this.subnetMaskLength = value
    }

    /**
     * @param value Action to be taken on the configuration. Example: Permit | Deny.
     */
    @JvmName("cuwmpajykjamuhfv")
    public suspend fun action(`value`: Either<String, CommunityActionTypes>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Action to be taken on the configuration. Example: Permit | Deny.
     */
    @JvmName("cfgkitywyjwmfwty")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, CommunityActionTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Action to be taken on the configuration. Example: Permit | Deny.
     */
    @JvmName("pelmamafkjdrqetk")
    public fun action(`value`: CommunityActionTypes) {
        val toBeMapped = Either.ofRight<String, CommunityActionTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Specify prefix-list bounds.
     */
    @JvmName("kgbwywgosvckejsx")
    public suspend fun condition(`value`: Either<String, Condition>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.condition = mapped
    }

    /**
     * @param value Specify prefix-list bounds.
     */
    @JvmName("hvaabkwphmltbeqt")
    public fun condition(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Condition>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.condition = mapped
    }

    /**
     * @param value Specify prefix-list bounds.
     */
    @JvmName("chpwyrxxkgubagnm")
    public fun condition(`value`: Condition) {
        val toBeMapped = Either.ofRight<String, Condition>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.condition = mapped
    }

    /**
     * @param value Network Prefix specifying IPv4/IPv6 packets to be permitted or denied. Example: 1.1.1.0/24 | 3FFE:FFFF:0:CD30::/126
     */
    @JvmName("etjferlbgttdqcip")
    public suspend fun networkPrefix(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkPrefix = mapped
    }

    /**
     * @param value Sequence to insert to/delete from existing route. Prefix lists are evaluated starting with the lowest sequence number and continue down the list until a match is made. Once a match is made, the permit or deny statement is applied to that network and the rest of the list is ignored.
     */
    @JvmName("vchmvrnlqdaofqfi")
    public suspend fun sequenceNumber(`value`: Double) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sequenceNumber = mapped
    }

    /**
     * @param value SubnetMaskLength gives the minimum NetworkPrefix length to be matched.Possible values for IPv4 are 1 - 32. Possible values of IPv6 are 1 - 128.
     */
    @JvmName("ccolnixytnxthqgk")
    public suspend fun subnetMaskLength(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnetMaskLength = mapped
    }

    internal fun build(): IpPrefixPropertiesIpPrefixRulesArgs = IpPrefixPropertiesIpPrefixRulesArgs(
        action = action ?: throw PulumiNullFieldException("action"),
        condition = condition,
        networkPrefix = networkPrefix ?: throw PulumiNullFieldException("networkPrefix"),
        sequenceNumber = sequenceNumber ?: throw PulumiNullFieldException("sequenceNumber"),
        subnetMaskLength = subnetMaskLength,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/IpPrefixPropertiesIpPrefixRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.IpPrefixPropertiesIpPrefixRulesArgs.builder
import com.pulumi.azurenative.managednetworkfabric.kotlin.enums.CommunityActionTypes
import com.pulumi.azurenative.managednetworkfabric.kotlin.enums.Condition
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property action Action to be taken on the configuration. Example: Permit | Deny.
 * @property condition Specify prefix-list bounds.
 * @property networkPrefix Network Prefix specifying IPv4/IPv6 packets to be permitted or denied. Example: 1.1.1.0/24 | 3FFE:FFFF:0:CD30::/126
 * @property sequenceNumber Sequence to insert to/delete from existing route. Prefix lists are evaluated starting with the lowest sequence number and continue down the list until a match is made. Once a match is made, the permit or deny statement is applied to that network and the rest of the list is ignored.
 * @property subnetMaskLength SubnetMaskLength gives the minimum NetworkPrefix length to be matched.Possible values for IPv4 are 1 - 32. Possible values of IPv6 are 1 - 128.
 */
public data class IpPrefixPropertiesIpPrefixRulesArgs(
    public val action: Output<Either<String, CommunityActionTypes>>,
    public val condition: Output<Either<String, Condition>>? = null,
    public val networkPrefix: Output<String>,
    public val sequenceNumber: Output<Double>,
    public val subnetMaskLength: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.IpPrefixPropertiesIpPrefixRulesArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.IpPrefixPropertiesIpPrefixRulesArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.IpPrefixPropertiesIpPrefixRulesArgs.builder()
            .action(
                action.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .condition(
                condition?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .networkPrefix(networkPrefix.applyValue({ args0 -> args0 }))
            .sequenceNumber(sequenceNumber.applyValue({ args0 -> args0 }))
            .subnetMaskLength(subnetMaskLength?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IpPrefixPropertiesIpPrefixRulesArgs].
 */
@PulumiTagMarker
public class IpPrefixPropertiesIpPrefixRulesArgsBuilder internal constructor() {
    private var action: Output<Either<String, CommunityActionTypes>>? = null

    private var condition: Output<Either<String, Condition>>? = null

    private var networkPrefix: Output<String>? = null

    private var sequenceNumber: Output<Double>? = null

    private var subnetMaskLength: Output<Int>? = null

    /**
     * @param value Action to be taken on the configuration. Example: Permit | Deny.
     */
    @JvmName("veitaxauhepiwfkk")
    public suspend fun action(`value`: Output<Either<String, CommunityActionTypes>>) {
        this.action = value
    }

    /**
     * @param value Specify prefix-list bounds.
     */
    @JvmName("nklgbsbklxtljhck")
    public suspend fun condition(`value`: Output<Either<String, Condition>>) {
        this.condition = value
    }

    /**
     * @param value Network Prefix specifying IPv4/IPv6 packets to be permitted or denied. Example: 1.1.1.0/24 | 3FFE:FFFF:0:CD30::/126
     */
    @JvmName("tmwpinkraeasxmpq")
    public suspend fun networkPrefix(`value`: Output<String>) {
        this.networkPrefix = value
    }

    /**
     * @param value Sequence to insert to/delete from existing route. Prefix lists are evaluated starting with the lowest sequence number and continue down the list until a match is made. Once a match is made, the permit or deny statement is applied to that network and the rest of the list is ignored.
     */
    @JvmName("anugohivkyvcejes")
    public suspend fun sequenceNumber(`value`: Output<Double>) {
        this.sequenceNumber = value
    }

    /**
     * @param value SubnetMaskLength gives the minimum NetworkPrefix length to be matched.Possible values for IPv4 are 1 - 32. Possible values of IPv6 are 1 - 128.
     */
    @JvmName("btfalarhovnkdjop")
    public suspend fun subnetMaskLength(`value`: Output<Int>) {
        this.subnetMaskLength = value
    }

    /**
     * @param value Action to be taken on the configuration. Example: Permit | Deny.
     */
    @JvmName("cweuylnonfsndpfk")
    public suspend fun action(`value`: Either<String, CommunityActionTypes>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Action to be taken on the configuration. Example: Permit | Deny.
     */
    @JvmName("ebolvgmpukgcbbcb")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, CommunityActionTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Action to be taken on the configuration. Example: Permit | Deny.
     */
    @JvmName("dgxnmufodiperjsh")
    public fun action(`value`: CommunityActionTypes) {
        val toBeMapped = Either.ofRight<String, CommunityActionTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Specify prefix-list bounds.
     */
    @JvmName("fwcxwsrfrbhsmsiy")
    public suspend fun condition(`value`: Either<String, Condition>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.condition = mapped
    }

    /**
     * @param value Specify prefix-list bounds.
     */
    @JvmName("ftpstraqpudvigku")
    public fun condition(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Condition>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.condition = mapped
    }

    /**
     * @param value Specify prefix-list bounds.
     */
    @JvmName("gsugbtpqmpqrkuqb")
    public fun condition(`value`: Condition) {
        val toBeMapped = Either.ofRight<String, Condition>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.condition = mapped
    }

    /**
     * @param value Network Prefix specifying IPv4/IPv6 packets to be permitted or denied. Example: 1.1.1.0/24 | 3FFE:FFFF:0:CD30::/126
     */
    @JvmName("kcjloppxtyomoivo")
    public suspend fun networkPrefix(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkPrefix = mapped
    }

    /**
     * @param value Sequence to insert to/delete from existing route. Prefix lists are evaluated starting with the lowest sequence number and continue down the list until a match is made. Once a match is made, the permit or deny statement is applied to that network and the rest of the list is ignored.
     */
    @JvmName("fydnsjvrpyqceegy")
    public suspend fun sequenceNumber(`value`: Double) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sequenceNumber = mapped
    }

    /**
     * @param value SubnetMaskLength gives the minimum NetworkPrefix length to be matched.Possible values for IPv4 are 1 - 32. Possible values of IPv6 are 1 - 128.
     */
    @JvmName("wbethuofnwqidwwg")
    public suspend fun subnetMaskLength(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnetMaskLength = mapped
    }

    internal fun build(): IpPrefixPropertiesIpPrefixRulesArgs = IpPrefixPropertiesIpPrefixRulesArgs(
        action = action ?: throw PulumiNullFieldException("action"),
        condition = condition,
        networkPrefix = networkPrefix ?: throw PulumiNullFieldException("networkPrefix"),
        sequenceNumber = sequenceNumber ?: throw PulumiNullFieldException("sequenceNumber"),
        subnetMaskLength = subnetMaskLength,
    )
}
